# Operators

??? abstract "`cryojax.ndimage.operators.AbstractImageOperator`"
    ::: cryojax.ndimage.operators.AbstractImageOperator
        options:
            members:
                - __call__

## Real-space

???+ abstract "`cryojax.ndimage.operators.AbstractRealOperator`"
    ::: cryojax.ndimage.operators.AbstractRealOperator
        options:
            members:
                - __call__

## Fourier-space

???+ abstract "`cryojax.ndimage.operators.AbstractFourierOperator`"
    ::: cryojax.ndimage.operators.AbstractFourierOperator
        options:
            members:
                - __call__
